@@ -3,12 +3,14 @@ Main interface for acm-pca service type definitions.
 
 Usage::
 
-    from mypy_boto3.acm_pca.type_defs import ASN1SubjectTypeDef
+    ```python
+    from mypy_boto3_acm_pca.type_defs import ASN1SubjectTypeDef
 
     data: ASN1SubjectTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
+from datetime import datetime
 from typing import List
 
 if sys.version_info >= (3, 8):
@@ -24,21 +26,22 @@ else:
 __all__ = (
     "ASN1SubjectTypeDef",
     "CertificateAuthorityConfigurationTypeDef",
+    "CertificateAuthorityTypeDef",
+    "CrlConfigurationTypeDef",
+    "PermissionTypeDef",
+    "RevocationConfigurationTypeDef",
+    "TagTypeDef",
     "CreateCertificateAuthorityAuditReportResponseTypeDef",
     "CreateCertificateAuthorityResponseTypeDef",
     "DescribeCertificateAuthorityAuditReportResponseTypeDef",
-    "CrlConfigurationTypeDef",
-    "RevocationConfigurationTypeDef",
-    "CertificateAuthorityTypeDef",
     "DescribeCertificateAuthorityResponseTypeDef",
     "GetCertificateAuthorityCertificateResponseTypeDef",
     "GetCertificateAuthorityCsrResponseTypeDef",
     "GetCertificateResponseTypeDef",
+    "GetPolicyResponseTypeDef",
     "IssueCertificateResponseTypeDef",
     "ListCertificateAuthoritiesResponseTypeDef",
-    "PermissionTypeDef",
     "ListPermissionsResponseTypeDef",
-    "TagTypeDef",
     "ListTagsResponseTypeDef",
     "PaginatorConfigTypeDef",
     "ValidityTypeDef",
@@ -78,10 +81,69 @@ CertificateAuthorityConfigurationTypeDef = TypedDict(
             "SHA384WITHRSA",
             "SHA512WITHRSA",
         ],
-        "Subject": ASN1SubjectTypeDef,
+        "Subject": "ASN1SubjectTypeDef",
     },
 )
 
+CertificateAuthorityTypeDef = TypedDict(
+    "CertificateAuthorityTypeDef",
+    {
+        "Arn": str,
+        "OwnerAccount": str,
+        "CreatedAt": datetime,
+        "LastStateChangeAt": datetime,
+        "Type": Literal["ROOT", "SUBORDINATE"],
+        "Serial": str,
+        "Status": Literal[
+            "CREATING", "PENDING_CERTIFICATE", "ACTIVE", "DELETED", "DISABLED", "EXPIRED", "FAILED"
+        ],
+        "NotBefore": datetime,
+        "NotAfter": datetime,
+        "FailureReason": Literal["REQUEST_TIMED_OUT", "UNSUPPORTED_ALGORITHM", "OTHER"],
+        "CertificateAuthorityConfiguration": "CertificateAuthorityConfigurationTypeDef",
+        "RevocationConfiguration": "RevocationConfigurationTypeDef",
+        "RestorableUntil": datetime,
+    },
+    total=False,
+)
+
+_RequiredCrlConfigurationTypeDef = TypedDict("_RequiredCrlConfigurationTypeDef", {"Enabled": bool})
+_OptionalCrlConfigurationTypeDef = TypedDict(
+    "_OptionalCrlConfigurationTypeDef",
+    {"ExpirationInDays": int, "CustomCname": str, "S3BucketName": str},
+    total=False,
+)
+
+
+class CrlConfigurationTypeDef(_RequiredCrlConfigurationTypeDef, _OptionalCrlConfigurationTypeDef):
+    pass
+
+
+PermissionTypeDef = TypedDict(
+    "PermissionTypeDef",
+    {
+        "CertificateAuthorityArn": str,
+        "CreatedAt": datetime,
+        "Principal": str,
+        "SourceAccount": str,
+        "Actions": List[Literal["IssueCertificate", "GetCertificate", "ListPermissions"]],
+        "Policy": str,
+    },
+    total=False,
+)
+
+RevocationConfigurationTypeDef = TypedDict(
+    "RevocationConfigurationTypeDef", {"CrlConfiguration": "CrlConfigurationTypeDef"}, total=False
+)
+
+_RequiredTagTypeDef = TypedDict("_RequiredTagTypeDef", {"Key": str})
+_OptionalTagTypeDef = TypedDict("_OptionalTagTypeDef", {"Value": str}, total=False)
+
+
+class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
+    pass
+
+
 CreateCertificateAuthorityAuditReportResponseTypeDef = TypedDict(
     "CreateCertificateAuthorityAuditReportResponseTypeDef",
     {"AuditReportId": str, "S3Key": str},
@@ -103,46 +165,9 @@ DescribeCertificateAuthorityAuditReportResponseTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredCrlConfigurationTypeDef = TypedDict("_RequiredCrlConfigurationTypeDef", {"Enabled": bool})
-_OptionalCrlConfigurationTypeDef = TypedDict(
-    "_OptionalCrlConfigurationTypeDef",
-    {"ExpirationInDays": int, "CustomCname": str, "S3BucketName": str},
-    total=False,
-)
-
-
-class CrlConfigurationTypeDef(_RequiredCrlConfigurationTypeDef, _OptionalCrlConfigurationTypeDef):
-    pass
-
-
-RevocationConfigurationTypeDef = TypedDict(
-    "RevocationConfigurationTypeDef", {"CrlConfiguration": CrlConfigurationTypeDef}, total=False
-)
-
-CertificateAuthorityTypeDef = TypedDict(
-    "CertificateAuthorityTypeDef",
-    {
-        "Arn": str,
-        "CreatedAt": datetime,
-        "LastStateChangeAt": datetime,
-        "Type": Literal["ROOT", "SUBORDINATE"],
-        "Serial": str,
-        "Status": Literal[
-            "CREATING", "PENDING_CERTIFICATE", "ACTIVE", "DELETED", "DISABLED", "EXPIRED", "FAILED"
-        ],
-        "NotBefore": datetime,
-        "NotAfter": datetime,
-        "FailureReason": Literal["REQUEST_TIMED_OUT", "UNSUPPORTED_ALGORITHM", "OTHER"],
-        "CertificateAuthorityConfiguration": CertificateAuthorityConfigurationTypeDef,
-        "RevocationConfiguration": RevocationConfigurationTypeDef,
-        "RestorableUntil": datetime,
-    },
-    total=False,
-)
-
 DescribeCertificateAuthorityResponseTypeDef = TypedDict(
     "DescribeCertificateAuthorityResponseTypeDef",
-    {"CertificateAuthority": CertificateAuthorityTypeDef},
+    {"CertificateAuthority": "CertificateAuthorityTypeDef"},
     total=False,
 )
 
@@ -160,45 +185,26 @@ GetCertificateResponseTypeDef = TypedDict(
     "GetCertificateResponseTypeDef", {"Certificate": str, "CertificateChain": str}, total=False
 )
 
+GetPolicyResponseTypeDef = TypedDict("GetPolicyResponseTypeDef", {"Policy": str}, total=False)
+
 IssueCertificateResponseTypeDef = TypedDict(
     "IssueCertificateResponseTypeDef", {"CertificateArn": str}, total=False
 )
 
 ListCertificateAuthoritiesResponseTypeDef = TypedDict(
     "ListCertificateAuthoritiesResponseTypeDef",
-    {"CertificateAuthorities": List[CertificateAuthorityTypeDef], "NextToken": str},
-    total=False,
-)
-
-PermissionTypeDef = TypedDict(
-    "PermissionTypeDef",
-    {
-        "CertificateAuthorityArn": str,
-        "CreatedAt": datetime,
-        "Principal": str,
-        "SourceAccount": str,
-        "Actions": List[Literal["IssueCertificate", "GetCertificate", "ListPermissions"]],
-        "Policy": str,
-    },
+    {"CertificateAuthorities": List["CertificateAuthorityTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListPermissionsResponseTypeDef = TypedDict(
     "ListPermissionsResponseTypeDef",
-    {"Permissions": List[PermissionTypeDef], "NextToken": str},
+    {"Permissions": List["PermissionTypeDef"], "NextToken": str},
     total=False,
 )
 
-_RequiredTagTypeDef = TypedDict("_RequiredTagTypeDef", {"Key": str})
-_OptionalTagTypeDef = TypedDict("_OptionalTagTypeDef", {"Value": str}, total=False)
-
-
-class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
-    pass
-
-
 ListTagsResponseTypeDef = TypedDict(
-    "ListTagsResponseTypeDef", {"Tags": List[TagTypeDef], "NextToken": str}, total=False
+    "ListTagsResponseTypeDef", {"Tags": List["TagTypeDef"], "NextToken": str}, total=False
 )
 
 PaginatorConfigTypeDef = TypedDict(
