@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 """
 Main interface for acm-pca service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.acm_pca import (
+
+    from mypy_boto3_acm_pca import ACMPCAClient
+    from mypy_boto3_acm_pca.waiter import (
         AuditReportCreatedWaiter,
         CertificateAuthorityCSRCreatedWaiter,
         CertificateIssuedWaiter,
@@ -15,12 +19,11 @@ Usage::
     audit_report_created_waiter: AuditReportCreatedWaiter = client.get_waiter("audit_report_created")
     certificate_authority_csr_created_waiter: CertificateAuthorityCSRCreatedWaiter = client.get_waiter("certificate_authority_csr_created")
     certificate_issued_waiter: CertificateIssuedWaiter = client.get_waiter("certificate_issued")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import TYPE_CHECKING
 from botocore.waiter import Waiter as Boto3Waiter
-from mypy_boto3_acm_pca.type_defs import WaiterConfigTypeDef
 
+from mypy_boto3_acm_pca.type_defs import WaiterConfigTypeDef
 
 __all__ = (
     "AuditReportCreatedWaiter",
@@ -31,7 +34,7 @@ __all__ = (
 
 class AuditReportCreatedWaiter(Boto3Waiter):
     """
-    [Waiter.AuditReportCreated documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.44/reference/services/acm-pca.html#ACMPCA.Waiter.AuditReportCreated)
+    [Waiter.AuditReportCreated documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/acm-pca.html#ACMPCA.Waiter.AuditReportCreated)
     """
 
     def wait(
@@ -41,24 +44,24 @@ class AuditReportCreatedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [AuditReportCreated.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.44/reference/services/acm-pca.html#ACMPCA.Waiter.AuditReportCreated.wait)
+        [AuditReportCreated.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/acm-pca.html#ACMPCA.Waiter.AuditReportCreated.wait)
         """
 
 
 class CertificateAuthorityCSRCreatedWaiter(Boto3Waiter):
     """
-    [Waiter.CertificateAuthorityCSRCreated documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.44/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateAuthorityCSRCreated)
+    [Waiter.CertificateAuthorityCSRCreated documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateAuthorityCSRCreated)
     """
 
     def wait(self, CertificateAuthorityArn: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
         """
-        [CertificateAuthorityCSRCreated.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.44/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateAuthorityCSRCreated.wait)
+        [CertificateAuthorityCSRCreated.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateAuthorityCSRCreated.wait)
         """
 
 
 class CertificateIssuedWaiter(Boto3Waiter):
     """
-    [Waiter.CertificateIssued documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.44/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateIssued)
+    [Waiter.CertificateIssued documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateIssued)
     """
 
     def wait(
@@ -68,5 +71,5 @@ class CertificateIssuedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [CertificateIssued.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.44/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateIssued.wait)
+        [CertificateIssued.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/acm-pca.html#ACMPCA.Waiter.CertificateIssued.wait)
         """
